@@ -19,12 +19,12 @@ Unit tests for Windows Hyper-V virtual switch neutron driver
 """
 
 import sys
+from unittest import mock
 
 import ddt
-import mock
 from neutron.agent import rpc as agent_rpc
-from neutron.common import rpc as n_rpc
-from neutron.common import topics
+from neutron_lib.agent import topics
+from neutron_lib import rpc as n_rpc
 from os_win import exceptions
 
 from networking_hyperv.neutron.agent import hyperv_neutron_agent as \
@@ -111,7 +111,8 @@ class TestHyperVNeutronAgent(base.HyperVBaseTestCase):
                          agent_configurations["tunneling_ip"])
 
     @mock.patch("networking_hyperv.neutron.trunk_driver.HyperVTrunkDriver")
-    @mock.patch("neutron.agent.securitygroups_rpc.SecurityGroupServerRpcApi")
+    @mock.patch("neutron.api.rpc.handlers.securitygroups_rpc."
+                "SecurityGroupServerRpcApi")
     @mock.patch("networking_hyperv.neutron.agent.hyperv_neutron_agent"
                 ".HyperVSecurityAgent")
     @mock.patch.object(layer2.Layer2Agent, "_setup")
