@@ -17,8 +17,8 @@
 Unit tests for the Hyper-V Security Groups Driver.
 """
 
-import mock
 from os_win import exceptions
+from unittest import mock
 
 from networking_hyperv.neutron import security_groups_driver as sg_driver
 from networking_hyperv.tests import base
@@ -430,7 +430,7 @@ class SecurityGroupRuleR2BaseTestCase(SecurityGroupRuleTestHelper):
     def _create_sg_rule(self, protocol=None, action=None, direction='egress'):
         protocol = protocol or self._FAKE_PROTOCOL
         action = action or self._FAKE_ACTION
-        remote_addr = (self._FAKE_DEST_IP_PREFIX if direction is 'egress' else
+        remote_addr = (self._FAKE_DEST_IP_PREFIX if direction == 'egress' else
                        self._FAKE_SOURCE_IP_PREFIX)
         return sg_driver.SecurityGroupRuleR2(
             self._acl('direction', self._FAKE_DIRECTION),
